@@ -21,7 +21,7 @@ class gpsdatetime():
     Jacques Beilin - ENSG/DPTS
 
     """
-    version = "2018-12-28"
+    version = "2021-11-11"
 
     # constant definitions
     _DAY = ['SUN', 'MON', 'TUE', 'WED', 'THU', 'FRI', 'SAT']
@@ -84,6 +84,7 @@ class gpsdatetime():
         snx = kwargs.get('snx', None)
         iso = kwargs.get('iso', None)
         rinex = kwargs.get('rinex', None)
+        timestamp = kwargs.get('timestamp', None)
 
         # attribute default values (lint)
         self._mjd = 0
@@ -173,6 +174,9 @@ class gpsdatetime():
 
         elif rinex:
             self.rinex_t(rinex)
+            
+        elif timestamp:
+            self.timestamp_t(timestamp)
 
         else:
             self.just_now() # par defaut on initialise  l'heure systme
@@ -490,6 +494,31 @@ class gpsdatetime():
                       float(list_strdate[2]), float(list_strdate[3]), \
                       float(list_strdate[4]), float(list_strdate[5]))
 
+    def timestamp_t(self, timestamp_str):
+        """Calculate all time elements from timestamp time string
+        
+        ex : "14/Dec/2021:07:37:10 +0100" 
+        
+        Input :
+          timestamp_str : timestamp time string
+
+        Output :
+          self : updated gpsdatetime object
+        """
+        delimiters = "/", ":", " "
+        regexPattern = '|'.join(map(re.escape, delimiters))
+        T = re.split(regexPattern, timestamp_str)
+        for i in range(len(gpsdatetime._MON)):
+            if re.search(T[1], gpsdatetime._MON[i], re.IGNORECASE):
+                T[1] = i + 1
+                break
+        for i in range(len(T)):
+            T[i] = float(T[i])
+        T[6] /= 100
+            
+        self.ymdhms_t(T[2], T[1], T[0], T[3], T[4], T[5])
+        self += 3600 * T[6]
+
     def add_s(self, s=0.0):
         """Add s seconds to a gpsdatetime object
         Input :
@@ -589,7 +618,7 @@ class gpsdatetime():
         return "%02d:%03d:%05d" % (self.yy, self.doy, self.dsec)
 
     def st_iso_epoch(self, ndecimal=0):
-        """Print iso time string
+        """ return iso time string
         """
         if ndecimal > 0:
             format_str = "%4.0f-%02.0f-%02.0fT%02.0f:%02.0f:%"\
@@ -599,6 +628,21 @@ class gpsdatetime():
 
         return format_str % (self.yyyy, self.mon, self.dd, self.hh, self.min, self.sec)
 
+    def st_timestamp_epoch(self, ndecimal=0):
+        """ return timestamp
+        Is is assumed that gpsdatetime object is in Z zone
+        """
+        Mon = gpsdatetime._MON[self.mon-1].capitalize()
+        
+        if ndecimal > 0:
+            format_str = "%02.0f/%3s/%4.0f:%02.0f:%02.0f:%"\
+                        + ("%02d.%1d" % (ndecimal+3, ndecimal)) + 'f +0000'
+        else:
+            format_str = "%02.0f/%3s/%4.0f:%02.0f:%02.0f:%02.0f +0000"
+            
+        return format_str % (self.dd, Mon, self.yyyy, self.hh, self.min, self.sec)
+  
+
     def __lt__(self, autre):
         """Surcharge de  < """
         return self.mjd < autre.mjd
@@ -695,4 +739,9 @@ if __name__ == "__main__":
     
     print(time_3.st_rinex_epoch())
     
+    ts = "14/Dec/2021:07:37:10.5 +0100"
+    
+    time_5 = gpsdatetime(timestamp=ts)
+    print(time_5.st_timestamp_epoch(4))
+    
     
\ No newline at end of file
